@@ -1,13 +1,10 @@
 from suds.client import Client
 from six import itervalues
 from .currencies import GPAY_CURRENCIES
-from .languages import GPAY_LANGUAGES
 
 GPAY_PRODUCTION_URL = "https://ecomms2s.sella.it/gestpay/gestpayws/WSs2s.asmx?WSDL"
 GPAY_TEST_URL = "https://testecomm.sella.it/gestpay/gestpayws/WSs2s.asmx?WSDL"
-
 GPAY_DEFAULT_CURRENCY = GPAY_CURRENCIES['EUR']['UICCode']
-GPAY_DEFAULT_LANGUAGE = GPAY_LANGUAGES['Italian']
 
 class GestPAY(object):
     def __init__(self, shop_login, test=False):
@@ -33,7 +30,7 @@ class GestPAY(object):
         data['expiryYear'] = exp_year
         data['uicCode'] = currency
 
-        for key, value in itervalues(kwargs):
+        for key, value in iteritems(kwargs):
             data[key] = value
 
         return self.make_request('callPagamS2S', data)
@@ -44,7 +41,7 @@ class GestPAY(object):
         data['shopTransactionId'] = transaction_id
         data['tokenValue'] = token
 
-        for key, value in iteritems(kwargs):
+        for key, value in itervalues(kwargs):
             data[key] = value
     
         return self.make_request('callPagamS2S', data)
@@ -137,6 +134,7 @@ class GestPAY(object):
 
         return self.make_request('CallRequestTokenS2S', data)
 
+
     def delete_token(self, card_token):
         data = self._prepare_request()
         data['tokenValue'] = card_token
@@ -149,8 +147,8 @@ class GestPAY(object):
             response = response_data['GestPayS2S']
         except Exception as e: 
             response = {"TransactionResult": "KO",
-                        "TransactionType": "",
-                        "ErrorCode": "-1",
-                        "ErrorDescription": "Token service not available ({})".format(e)}
+                 "TransactionType": "",
+                 "ErrorCode": "-1",
+                 "ErrorDescription": "Token service not available ({})".format(e)}
 
-        return response
\ No newline at end of file
+        return response
